@@ -3,10 +3,16 @@ package Net::Async::Github;
 use strict;
 use warnings;
 
-our $VERSION = '0.005';
+our $VERSION = '0.006';
+our $AUTHORITY = 'cpan:TEAM'; # AUTHORITY
 
 use parent qw(IO::Async::Notifier);
 
+no indirect;
+use utf8;
+
+=encoding utf8
+
 =head1 NAME
 
 Net::Async::Github - support for the L<https://github.com> REST API with L<IO::Async>
@@ -562,9 +568,9 @@ sub core_rate_limit {
             )->on_done(sub {
                 my $data = shift;
                 $log->tracef("Github rate limit response was %s", $data);
+                $rl->reset->set_numeric($data->{resources}{core}{reset});
                 $rl->limit->set_numeric($data->{resources}{core}{limit});
                 $rl->remaining->set_numeric($data->{resources}{core}{remaining});
-                $rl->reset->set_numeric($data->{resources}{core}{reset});
             })
         );
         $rl;
@@ -777,7 +783,7 @@ sub http_get {
         my ($resp) = @_;
         $log->tracef("Github response: %s", $resp->as_string("\n"));
         # If we had ratelimiting headers, apply them
-        for my $k (qw(Limit Remaining Reset)) {
+        for my $k (qw(Reset Limit Remaining)) {
             if(defined(my $v = $resp->header('X-RateLimit-' . $k))) {
                 my $method = lc $k;
                 $self->core_rate_limit->$method->set_numeric($v);
@@ -1233,9 +1239,9 @@ sub ws {
 
 =head1 AUTHOR
 
-Tom Molesworth <TEAM@cpan.org>
+Tom Molesworth <TEAM@cpan.org>, with contributions from C<< @chylli-binary >>.
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2014-2019. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2014-2020. Licensed under the same terms as Perl itself.
 
